==> dps-data-model-0.0.18-sources.jar: pl/topteam/dps/model/main_gen/InstytucjaDoplacajaca.java <==
package pl.topteam.dps.model.main_gen;

import pl.topteam.dps.generic.GenericDPSObject;

public abstract class InstytucjaDoplacajaca extends GenericDPSObject {
    /**
     * INSTYTUCJA_DOPLACAJACA.ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long id;

    /**
     * INSTYTUCJA_DOPLACAJACA.ADRES_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long adresId;

    /**
     * INSTYTUCJA_DOPLACAJACA.DOMYSLNA
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Boolean domyslna;

    /**
     * INSTYTUCJA_DOPLACAJACA.EMERYTALNO_RENTOWA
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Boolean emerytalnoRentowa;

    /**
     * INSTYTUCJA_DOPLACAJACA.NAZWA
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private String nazwa;

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return INSTYTUCJA_DOPLACAJACA.ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * INSTYTUCJA_DOPLACAJACA.ID
     *
     * @param id
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return INSTYTUCJA_DOPLACAJACA.ADRES_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getAdresId() {
        return adresId;
    }

    /**
     * INSTYTUCJA_DOPLACAJACA.ADRES_ID
     *
     * @param adresId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setAdresId(Long adresId) {
        this.adresId = adresId;
    }

    /**
     * @return INSTYTUCJA_DOPLACAJACA.DOMYSLNA
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Boolean getDomyslna() {
        return domyslna;
    }

    /**
     * INSTYTUCJA_DOPLACAJACA.DOMYSLNA
     *
     * @param domyslna
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setDomyslna(Boolean domyslna) {
        this.domyslna = domyslna;
    }

    /**
     * @return INSTYTUCJA_DOPLACAJACA.EMERYTALNO_RENTOWA
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Boolean getEmerytalnoRentowa() {
        return emerytalnoRentowa;
    }

    /**
     * INSTYTUCJA_DOPLACAJACA.EMERYTALNO_RENTOWA
     *
     * @param emerytalnoRentowa
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setEmerytalnoRentowa(Boolean emerytalnoRentowa) {
        this.emerytalnoRentowa = emerytalnoRentowa;
    }

    /**
     * @return INSTYTUCJA_DOPLACAJACA.NAZWA
     * @mbggenerated 2014-03-10 10:45:37
     */
    public String getNazwa() {
        return nazwa;
    }

    /**
     * INSTYTUCJA_DOPLACAJACA.NAZWA
     *
     * @param nazwa
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setNazwa(String nazwa) {
        this.nazwa = nazwa == null ? null : nazwa.trim();
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        InstytucjaDoplacajaca other = (InstytucjaDoplacajaca) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getAdresId() == null ? other.getAdresId() == null : this.getAdresId().equals(other.getAdresId()))
            && (this.getDomyslna() == null ? other.getDomyslna() == null : this.getDomyslna().equals(other.getDomyslna()))
            && (this.getEmerytalnoRentowa() == null ? other.getEmerytalnoRentowa() == null : this.getEmerytalnoRentowa().equals(other.getEmerytalnoRentowa()))
            && (this.getNazwa() == null ? other.getNazwa() == null : this.getNazwa().equals(other.getNazwa()));
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getAdresId() == null) ? 0 : getAdresId().hashCode());
        result = prime * result + ((getDomyslna() == null) ? 0 : getDomyslna().hashCode());
        result = prime * result + ((getEmerytalnoRentowa() == null) ? 0 : getEmerytalnoRentowa().hashCode());
        result = prime * result + ((getNazwa() == null) ? 0 : getNazwa().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", adresId=").append(adresId);
        sb.append(", domyslna=").append(domyslna);
        sb.append(", emerytalnoRentowa=").append(emerytalnoRentowa);
        sb.append(", nazwa=").append(nazwa);
        sb.append("]");
        return sb.toString();
    }
}

==> dps-data-model-0.0.23-sources.jar: pl/topteam/dps/model/main_gen/InstytucjaDoplacajaca.java <==
package pl.topteam.dps.model.main_gen;

import pl.topteam.dps.model.main_gen.GenericDPSObject;

public abstract class InstytucjaDoplacajaca extends GenericDPSObject {
    /**
     * INSTYTUCJA_DOPLACAJACA.ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long id;

    /**
     * INSTYTUCJA_DOPLACAJACA.ADRES_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long adresId;

    /**
     * INSTYTUCJA_DOPLACAJACA.DOMYSLNA
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Boolean domyslna;

    /**
     * INSTYTUCJA_DOPLACAJACA.EMERYTALNO_RENTOWA
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Boolean emerytalnoRentowa;

    /**
     * INSTYTUCJA_DOPLACAJACA.NAZWA
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private String nazwa;

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return INSTYTUCJA_DOPLACAJACA.ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * INSTYTUCJA_DOPLACAJACA.ID
     *
     * @param id
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return INSTYTUCJA_DOPLACAJACA.ADRES_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getAdresId() {
        return adresId;
    }

    /**
     * INSTYTUCJA_DOPLACAJACA.ADRES_ID
     *
     * @param adresId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setAdresId(Long adresId) {
        this.adresId = adresId;
    }

    /**
     * @return INSTYTUCJA_DOPLACAJACA.DOMYSLNA
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Boolean getDomyslna() {
        return domyslna;
    }

    /**
     * INSTYTUCJA_DOPLACAJACA.DOMYSLNA
     *
     * @param domyslna
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setDomyslna(Boolean domyslna) {
        this.domyslna = domyslna;
    }

    /**
     * @return INSTYTUCJA_DOPLACAJACA.EMERYTALNO_RENTOWA
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Boolean getEmerytalnoRentowa() {
        return emerytalnoRentowa;
    }

    /**
     * INSTYTUCJA_DOPLACAJACA.EMERYTALNO_RENTOWA
     *
     * @param emerytalnoRentowa
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setEmerytalnoRentowa(Boolean emerytalnoRentowa) {
        this.emerytalnoRentowa = emerytalnoRentowa;
    }

    /**
     * @return INSTYTUCJA_DOPLACAJACA.NAZWA
     * @mbggenerated 2014-03-13 16:02:38
     */
    public String getNazwa() {
        return nazwa;
    }

    /**
     * INSTYTUCJA_DOPLACAJACA.NAZWA
     *
     * @param nazwa
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setNazwa(String nazwa) {
        this.nazwa = nazwa == null ? null : nazwa.trim();
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        InstytucjaDoplacajaca other = (InstytucjaDoplacajaca) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getAdresId() == null ? other.getAdresId() == null : this.getAdresId().equals(other.getAdresId()))
            && (this.getDomyslna() == null ? other.getDomyslna() == null : this.getDomyslna().equals(other.getDomyslna()))
            && (this.getEmerytalnoRentowa() == null ? other.getEmerytalnoRentowa() == null : this.getEmerytalnoRentowa().equals(other.getEmerytalnoRentowa()))
            && (this.getNazwa() == null ? other.getNazwa() == null : this.getNazwa().equals(other.getNazwa()));
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getAdresId() == null) ? 0 : getAdresId().hashCode());
        result = prime * result + ((getDomyslna() == null) ? 0 : getDomyslna().hashCode());
        result = prime * result + ((getEmerytalnoRentowa() == null) ? 0 : getEmerytalnoRentowa().hashCode());
        result = prime * result + ((getNazwa() == null) ? 0 : getNazwa().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", adresId=").append(adresId);
        sb.append(", domyslna=").append(domyslna);
        sb.append(", emerytalnoRentowa=").append(emerytalnoRentowa);
        sb.append(", nazwa=").append(nazwa);
        sb.append("]");
        return sb.toString();
    }
}
